@@ -10,12 +10,12 @@ WebService::MIAB - manage emails (users) and alias addresses on a mail-in-a-box
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =cut
 
 use version;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moo;
 with 'WebService::Client';
@@ -24,6 +24,7 @@ use LWP::UserAgent;
 use MIME::Base64;
 use Carp qw(croak);
 use re qw(is_regexp);
+use List::MoreUtils qw(uniq);
 
 use JSON;
 my $json = JSON->new->allow_nonref;
@@ -271,9 +272,7 @@ sub get_domains{
 		push( @result, $_->{'domain'} );
 	} @{$aliases};
 
-	# TODO - unify
-
-	return @result;
+	return (uniq @result);
 }
 
 
